#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.15.1.2
visibility:           public
id:                   gitit-0.15.1.2-DF78DMH0d4s8PCugKigVtB
key:                  gitit-0.15.1.2-DF78DMH0d4s8PCugKigVtB
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  5dd0e7bf2b16b49c7fbfc17293b16df1
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Rpxnow Network.Gitit.Server Network.Gitit.State
    Network.Gitit.Types Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.15.1.2-DF78DMH0d4s8PCugKigVtB
depends:
    HStringTemplate-0.8.8-8VzVvQGkJrd11oj6857Li2
    HTTP-4000.4.1-FD6mrvTTgPoGkAJSe0MzTH
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.2.0-CZIrLrIqsbVBSATKMNLvxW base-4.18.2.1
    base64-bytestring-1.2.1.0-EIdFd4GQy0qAj5NJhNKnbU
    blaze-html-0.9.2.0-INVwOgfGe5U7282dcB0sT7 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-Kn2e0LxjXkk52RPLLf776o
    feed-1.3.2.1-Ed30uj5QOcJLXH8mqLX25E filepath-1.4.300.1
    filestore-0.6.5.1-AjMzdWSldzm9EnXw9yKz7c ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-6qK7lAEsHyJ1yw3uQ7wpmb
    hoauth2-2.14.0-9pKVUTcMJj034RaJ6OsKnP
    hslogger-1.3.2.0-9vDdAyjm1L2Jp1uFnaNdQk
    http-client-tls-0.3.6.4-IPAuQ8vgNUFKOSQuiXp27m
    http-conduit-2.3.9.1-2h1lq59T36j5qSVbTmccvx
    json-0.10-AicLo8NCKMCG9kjIGzNeec mtl-2.3.1
    network-3.1.4.0-H0nXkJCBCRX48TBw5xI3IF
    network-bsd-2.8.1.0-Cvii4T8EL4zI63dQDjgRNj
    network-uri-2.6.4.2-DZsK30J0JA75RbwwKgdhQI
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.0.5-6pAIdwhrU2yDlFeoj1dxmG
    pandoc-3.6-7reeEnI7UCR4OqmwkjX6Dg
    pandoc-types-1.23.1-FEpWUS1tRB02u75CHjULeJ parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-I2hvYvdtJZ4FW6nqBcrw73
    recaptcha-0.1.0.4-9dtJaRoIWlrFeXwC222RTk
    safe-0.3.21-9LQlXkQq5dJFD7zwcgmche
    skylighting-0.14.4-2miOTj4hKzf8PbBgwU0Mla
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 syb-0.7.3-9bhoOc0glOT5F9ECx30Xje
    tagsoup-0.14.8-2WyprBwiDzy2R2uEcQEyJk
    temporary-1.3-3Yp3Uk7QhUj5YazPlVZPPv text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-Eky8E3BhHPR5V5TmcScAKA
    url-2.1.3-4RTfhxhLQ3wA2dxVj2PtKK
    utf8-string-1.0.2-Jktg7mszcNkI00pgM6b6il
    uuid-1.3.16.1-HbcpB07kmGCJwEV4aE8eHw xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-Ew3EfnkQ13FH4VhThgCeuS
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-BSw39AT7hu8DqsOlzLNiJp
    zlib-0.7.0.0-1vz9i9SXybSK4MlJboJZnQ

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

